@@ -8,10 +8,8 @@ import random
 import re
 from typing import Any, Callable, Dict, List, Optional, Tuple, Union
 
-# from .prefetch_generator import PrefetchGenerator
-# from ..utils import is_available
-from kmspy.data.prefetch_generator import PrefetchGenerator
-from kmspy.utils import is_available
+from .prefetch_generator import PrefetchGenerator
+from ..utils import is_available
 
 import numpy as np
 if is_available("tensorflow"):
